@@ -14,17 +14,20 @@ class TaskDataEntry(Model):
       {
         "task_key": "407fdd93-687a-46bb-b578-89eb96b4109d",
         "datapoint_uri": "https://domain.com/file1.jpg",
+        "datapoint_text": {},
         "datapoint_hash": "f4acbe8562907183a484498ba901bfe5c5503aaa"
       },
       {
         "task_key": "20bd4f3e-4518-4602-b67a-1d8dfabcce0c",
         "datapoint_uri": "https://domain.com/file2.jpg",
+        "datapoint_text": { "en": "any question here"},
         "datapoint_hash": "f4acbe8562907183a484498ba901bfe5c5503aaa"
       }
     ]
     """
     task_key = UUIDType()
-    datapoint_uri = URLType(required=True, min_length=10)
+    datapoint_uri = URLType()
+    datapoint_text = DictType(StringType())
     datapoint_hash = StringType()
     metadata = DictType(
       UnionType([
@@ -39,6 +42,18 @@ class TaskDataEntry(Model):
             raise ValidationError("metadata should be < 1024")
         return value
 
+    def validate_datapoint_uri(self, data, value):
+        """
+        Validate datapoint_uri.
+
+        Raise error if no datapoint_text and no value for URI or if length of URI less than 10.
+        """
+        if not value and not data.get('datapoint_text'):
+            raise ValidationError("datapoint_uri is missing.")
+        if value and len(value) < 10 and not data.get('datapoint_text'):
+            raise ValidationError("datapoint_uri length is less than 10")
+        return value
+
 
 def validate_content_type(uri: str) -> None:
     """ Validate uri content type """
